@@ -1,6 +1,6 @@
 #!/bin/bash
 #set -vx
-mversion="V11.1"
+mversion="V12.1"
 ASTERISK_4="1.4.44"
 ASTERISK_4_OLD="1.4.11"
 ASTERISK_6_2="1.6.2.24"
@@ -28,7 +28,7 @@ if [ ! "$?" = "0" ];then
 fi
 
 #Check Asterisk Version
-asteriskversion=`asterisk -V|grep Asterisk| cut -d ' ' -f 2` 
+asteriskversion=`asterisk -V|grep Asterisk| cut -d ' ' -f 2`
 #Asterisk Versions parsing
 eval `echo $asteriskversion |  sed -n 's_\([0-9]*\)\.\([0-9]*\)\.\([0-9]*\).*_ astver1="\1" astver2="\2" astver3="\3"_p'`
 [ "$astver2" == "6" ] && eval `echo $asteriskversion |  sed -n 's_[0-9]*\.[0-9]*\.[0-9]*\.\([0-9]*\).*_ astver4="\1"_p'`
@@ -117,7 +117,11 @@ install -m $perm_dir $src/bin/safe_openvxi $dst/usr/sbin/
 
 if [ "1" = "1" ]; then \
 	if [ -f /etc/redhat-release -o -f /etc/fedora-release ]; then \
+		if [ -f /var/www/html/admin/modules/core/module.xml ]; then \
+		install -m $perm_dir $src/bin/rc.freepbx.openvxi /etc/rc.d/init.d/openvxi; \
+		else \
 		install -m $perm_dir $src/bin/rc.redhat.openvxi /etc/rc.d/init.d/openvxi; \
+		fi; \
 		/sbin/chkconfig --add openvxi; \
 	elif [ -f /etc/debian_version ]; then \
   install -m $perm_dir $src/bin/rc.debian.openvxi /etc/init.d/openvxi; \
@@ -168,5 +172,31 @@ install -m $perm_files $src/sounds/* $dst/$soundsdir
 #echo "Installing grammars..."
 #install -m $perm_files $src/grammars/* $dst/var/lib/openvxi/grammars/
 
+if [ -f /var/www/html/admin/modules/core/module.xml ]; then
+    echo "Installing FreePBX Module"
+    cp -r $src/www/freepbx/admin/modules/vxml $dst/var/www/html/admin/modules
+    chown -R asterisk:asterisk $dst/var/www/html/admin/modules/vxml
+    rm $dst/etc/asterisk/vxml.conf
+    touch $dst/etc/asterisk/vxml.conf
+    chown asterisk:asterisk  $dst/etc/asterisk/vxml.conf
+    echo
+    echo "Remember to :"
+    echo "  Enable unsigned modules."
+    echo "  Finish to install the module from the Module Admin menu."
+fi
+
+if [ -d /var/www/html/modules/pbxadmin ]; then
+    echo "Installing Elastix Module"
+    cp -r $dst/var/www/html/modules/pbxadmin/themes/default/main.tpl $dst/var/www/html/modules/pbxadmin/themes/default/main.tpl.org
+    cp -r $src/www/elastix/modules/* $dst/var/www/html/modules
+    chown -R asterisk:asterisk $dst/var/www/html/modules/vxml_log
+    sqlite3 /var/www/db/menu.db "delete from menu where id='vxml_log'"
+    sqlite3 /var/www/db/menu.db "insert into menu values('vxml_log', 'reports', '', 'VoiceXML logs', 'module','4')"
+    sqlite3 /var/www/db/acl.db "delete from acl_resource where name='vxml_log'"
+    sqlite3 /var/www/db/acl.db "insert into acl_resource values(1000, 'vxml_log', 'VoiceXML Logs')"
+    sqlite3 /var/www/db/acl.db "delete from acl_group_permission where id_resource='1000'"
+    sqlite3 /var/www/db/acl.db "insert into acl_group_permission values(180, 1, 1, 1000)"
+fi
+
 echo "--- VXIasterisk $mversion installation has finished ---"
 
